addressing

package
v0.0.0-...-658d513 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 6, 2024 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Overview

Package addressing provides addressing defines and helpers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Absolute

type Absolute uint16

Absolute indicates that the parameter for the instruction is an absolute address.

type AbsoluteX

type AbsoluteX uint16

AbsoluteX defines absolute addressing using the X register

type AbsoluteY

type AbsoluteY uint16

AbsoluteY defines absolute addressing using the Y register

type AccessMode

type AccessMode int

AccessMode defines an address access mode.

const (
	NoAccess        AccessMode = 0
	ReadAccess      AccessMode = 1
	WriteAccess     AccessMode = 2
	ReadWriteAccess AccessMode = 3
)

address accessing modes.

type AccessModeConstant

type AccessModeConstant struct {
	Constant string
	Mode     AccessMode
}

AccessModeConstant is used to specify for every memory address what access mode applies to it. A memory address like 0x4017 has a different meaning depending on the type of access.

type Accumulator

type Accumulator int

Accumulator indicates that the parameter for the instruction is the accumulator.

type Indirect

type Indirect uint16

Indirect indicates that the parameter for the instruction is using indirect addressing using an address and an optional X or Y register. For usage with a register, the indirect address is a byte and refers to the zero page.

type IndirectResolved

type IndirectResolved uint16

IndirectResolved indicates that the parameter for the instruction is using indirect addressing using an address and an optional X or Y register. The final address including the memory read bug has been resolved.

type IndirectX

type IndirectX uint16

IndirectX defines indirect addressing using the X register

type IndirectY

type IndirectY uint16

IndirectY defines indirect addressing using the Y register

type Mode

type Mode int

Mode defines an address mode.

const (
	NoAddressing      Mode = 0
	ImpliedAddressing Mode = 1 << iota
	AccumulatorAddressing
	ImmediateAddressing
	AbsoluteAddressing
	ZeroPageAddressing
	AbsoluteXAddressing
	ZeroPageXAddressing
	AbsoluteYAddressing
	ZeroPageYAddressing
	IndirectAddressing
	IndirectXAddressing
	IndirectYAddressing
	RelativeAddressing
)

addressing modes.

type ZeroPage

type ZeroPage uint8

ZeroPage indicates that the parameter for the instruction is addressing the zero page.

type ZeroPageX

type ZeroPageX uint8

ZeroPageX defines zeropage addressing using the X register

type ZeroPageY

type ZeroPageY uint8

ZeroPageY defines zeropage addressing using the Y register

Jump to