package
Version:
v0.0.0-...-658d513
Opens a new window with list of versions in this module.
Published: Oct 6, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package assert contains test assertion helpers.
-
func Equal(t *testing.T, expected, actual any, errorMessage ...string)
-
func Error(t *testing.T, err error, expectedError string, errorMessage ...string)
-
func False(t *testing.T, value bool, errorMessage ...string)
-
func NoError(t *testing.T, err error, errorMessage ...string)
-
func True(t *testing.T, value bool, errorMessage ...string)
Equal asserts that two objects are equal.
Error asserts that a function returned an error.
False asserts that the specified value is false.
NoError asserts that a function returned no error.
True asserts that the specified value is true.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.