buildinfo

package
v0.0.0-...-658d513 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 6, 2024 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package buildinfo formats build information that is embedded into the binaries.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Version

func Version(version, commit, date string) string

Version builds a version string based on binary release information.

Types

This section is empty.

Jump to